==> QupZilla-1.3.5.tar.gz: QupZilla-1.3.5/src/plugins/GreaseMonkey/translations/el_GR.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="el">
<context>
    <name>GM_AddScriptDialog</name>
    <message>
        <location filename="../gm_addscriptdialog.ui" line="14"/>
        <source>GreaseMonkey Installation</source>
        <translation>Εγκατάσταση του GreaseMonkey</translation>
    </message>
    <message>
        <location filename="../gm_addscriptdialog.ui" line="51"/>
        <source>&lt;h3&gt;GreaseMonkey Installation&lt;/h3&gt;</source>
        <translation>&lt;h3&gt;Εγκατάσταση του GreaseMonkey&lt;/h3&gt;</translation>
    </message>
    <message>
        <location filename="../gm_addscriptdialog.ui" line="73"/>
        <source>You are about to install this userscript into GreaseMonkey:</source>
        <translation>Είστε έτοιμοι να εγκαταστήσετε αυτό το σενάριο εντολών χρηστη στο GreaseMonkey:</translation>
    </message>
    <message>
        <location filename="../gm_addscriptdialog.ui" line="86"/>
        <source>&lt;b&gt;You should only install scripts from sources you trust!&lt;/b&gt;</source>
        <translation>&lt;b&gt;Θα πρέπει να εγκαθιστάτε σενάρια εντολών από πηγές που εμπιστεύεστε!&lt;b/&gt;</translation>
    </message>
    <message>
        <location filename="../gm_addscriptdialog.ui" line="96"/>
        <source>Are you sure you want to install it?</source>
        <translation>Είστε σιγουροι ότι θέλετε να το εγκαταστήσετε;</translation>
    </message>
    <message>
        <location filename="../gm_addscriptdialog.ui" line="114"/>
        <source>Show source code of script</source>
        <translation>Εμφάνιση πηγαίου κώδικα για το σενάριο εντολών</translation>
    </message>
    <message>
        <location filename="../gm_addscriptdialog.cpp" line="48"/>
        <source>&lt;p&gt;runs at&lt;br/&gt;&lt;i&gt;%1&lt;/i&gt;&lt;/p&gt;</source>
        <translation>&lt;p&gt;τρέχει σε&lt;br/&gt;&lt;i&gt;%1&lt;/i&gt;&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../gm_addscriptdialog.cpp" line="52"/>
        <source>&lt;p&gt;does not run at&lt;br/&gt;&lt;i&gt;%1&lt;/i&gt;&lt;/p&gt;</source>
        <translation>&lt;p&gt;δεν τρέχει σε&lt;br/&gt;&lt;i&gt;%1&lt;/i&gt;&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../gm_addscriptdialog.cpp" line="82"/>
        <source>Cannot install script</source>
        <translation>Αδυναμία εγκατάστασης σεναρίου εντολής</translation>
    </message>
    <message>
        <location filename="../gm_addscriptdialog.cpp" line="85"/>
        <source>&apos;%1&apos; installed successfully</source>
        <translation>&apos;%1&apos; εγκαταστάθηκε επιτυχώς</translation>
    </message>
</context>
<context>
    <name>GM_Downloader</name>
    <message>
        <location filename="../gm_downloader.cpp" line="144"/>
        <source>&apos;%1&apos; is already installed</source>
        <translation>&apos;%1&apos; již je nainstalován</translation>
    </message>
</context>
<context>
    <name>GM_Manager</name>
    <message>
        <location filename="../gm_manager.cpp" line="172"/>
        <source>GreaseMonkey</source>
        <translation>GreaseMonkey</translation>
    </message>
</context>
<context>
    <name>GM_Notification</name>
    <message>
        <location filename="../gm_notification.ui" line="45"/>
        <source>This script can be installed with the GreaseMonkey plugin.</source>
        <translation>Tento skript může být nainstalován do GreaseMonkey rozšíření.</translation>
    </message>
    <message>
        <location filename="../gm_notification.ui" line="65"/>
        <source>Install</source>
        <translation>Instalovat</translation>
    </message>
    <message>
        <location filename="../gm_notification.cpp" line="49"/>
        <source>Cannot install script</source>
        <translation>Nelze nainstalovat skript</translation>
    </message>
    <message>
        <location filename="../gm_notification.cpp" line="57"/>
        <source>&apos;%1&apos; installed successfully</source>
        <translation>&apos;%1&apos; úspěšně nainstalován</translation>
    </message>
</context>
<context>
    <name>GM_Settings</name>
    <message>
        <location filename="../settings/gm_settings.ui" line="14"/>
        <source>GreaseMonkey Scripts</source>
        <translation>GreaseMonkey Skripty</translation>
    </message>
    <message>
        <location filename="../settings/gm_settings.ui" line="51"/>
        <source>&lt;h3&gt;GreaseMonkey Scripts&lt;/h3&gt;</source>
        <translation>&lt;h3&gt;GreaseMonkey Skripty&lt;/h3&gt;</translation>
    </message>
    <message>
        <location filename="../settings/gm_settings.ui" line="73"/>
        <source>Double clicking script will show additional information</source>
        <translation>Dvojtý klik na skript zobrazí podrobnosti</translation>
    </message>
    <message>
        <location filename="../settings/gm_settings.ui" line="153"/>
        <source>More scripts can be downloaded from</source>
        <translation>Více skriptů lze stáhnout z</translation>
    </message>
    <message>
        <location filename="../settings/gm_settings.ui" line="196"/>
        <source>Open scripts directory</source>
        <translation>Otevřít složku se skripty</translation>
    </message>
    <message>
        <location filename="../settings/gm_settings.cpp" line="68"/>
        <source>Remove script</source>
        <translation>Odstranit skript</translation>
    </message>
    <message>
        <location filename="../settings/gm_settings.cpp" line="69"/>
        <source>Are you sure you want to remove &apos;%1&apos;?</source>
        <translation>Opravdu chcete odstranit &apos;%1&apos;?</translation>
    </message>
</context>
<context>
    <name>GM_SettingsScriptInfo</name>
    <message>
        <location filename="../settings/gm_settingsscriptinfo.ui" line="19"/>
        <source>Name:</source>
        <translation>Název:</translation>
    </message>
    <message>
        <location filename="../settings/gm_settingsscriptinfo.ui" line="29"/>
        <source>Version:</source>
        <translation>Verze:</translation>
    </message>
    <message>
        <location filename="../settings/gm_settingsscriptinfo.ui" line="39"/>
        <source>URL:</source>
        <translation>URL:</translation>
    </message>
    <message>
        <location filename="../settings/gm_settingsscriptinfo.ui" line="49"/>
        <source>Start at:</source>
        <translation>Běží na:</translation>
    </message>
    <message>
        <location filename="../settings/gm_settingsscriptinfo.ui" line="59"/>
        <source>Description:</source>
        <translation>Popis:</translation>
    </message>
    <message>
        <location filename="../settings/gm_settingsscriptinfo.ui" line="69"/>
        <source>Runs at:</source>
        <translation>Spouští se na:</translation>
    </message>
    <message>
        <location filename="../settings/gm_settingsscriptinfo.ui" line="79"/>
        <source>Does not run at:</source>
        <translation>Nespouští se na:</translation>
    </message>
    <message>
        <location filename="../settings/gm_settingsscriptinfo.cpp" line="27"/>
        <source>Script Details of %1</source>
        <translation>Detaily skriptu %1</translation>
    </message>
</context>
</TS>

==> QupZilla-1.4.3.tar.gz: QupZilla-1.4.3/src/plugins/GreaseMonkey/translations/el_GR.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="el_GR" version="2.0">
<context>
    <name>GM_AddScriptDialog</name>
    <message>
        <location filename="../gm_addscriptdialog.ui" line="14"/>
        <source>GreaseMonkey Installation</source>
        <translation>Εγκατάσταση του GreaseMonkey</translation>
    </message>
    <message>
        <location filename="../gm_addscriptdialog.ui" line="51"/>
        <source>&lt;h3&gt;GreaseMonkey Installation&lt;/h3&gt;</source>
        <translation>&lt;h3&gt;Εγκατάσταση του GreaseMonkey&lt;/h3&gt;</translation>
    </message>
    <message>
        <location filename="../gm_addscriptdialog.ui" line="73"/>
        <source>You are about to install this userscript into GreaseMonkey:</source>
        <translation>Είστε έτοιμοι να εγκαταστήσετε αυτό το σενάριο εντολών χρηστη στο GreaseMonkey:</translation>
    </message>
    <message>
        <location filename="../gm_addscriptdialog.ui" line="86"/>
        <source>&lt;b&gt;You should only install scripts from sources you trust!&lt;/b&gt;</source>
        <translation>&lt;b&gt;Θα πρέπει να εγκαθιστάτε σενάρια εντολών από πηγές που εμπιστεύεστε!&lt;b/&gt;</translation>
    </message>
    <message>
        <location filename="../gm_addscriptdialog.ui" line="96"/>
        <source>Are you sure you want to install it?</source>
        <translation>Είστε σιγουροι ότι θέλετε να το εγκαταστήσετε;</translation>
    </message>
    <message>
        <location filename="../gm_addscriptdialog.ui" line="114"/>
        <source>Show source code of script</source>
        <translation>Εμφάνιση πηγαίου κώδικα για το σενάριο εντολών</translation>
    </message>
    <message>
        <location filename="../gm_addscriptdialog.cpp" line="48"/>
        <source>&lt;p&gt;runs at&lt;br/&gt;&lt;i&gt;%1&lt;/i&gt;&lt;/p&gt;</source>
        <translation>&lt;p&gt;τρέχει σε&lt;br/&gt;&lt;i&gt;%1&lt;/i&gt;&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../gm_addscriptdialog.cpp" line="52"/>
        <source>&lt;p&gt;does not run at&lt;br/&gt;&lt;i&gt;%1&lt;/i&gt;&lt;/p&gt;</source>
        <translation>&lt;p&gt;δεν τρέχει σε&lt;br/&gt;&lt;i&gt;%1&lt;/i&gt;&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../gm_addscriptdialog.cpp" line="82"/>
        <source>Cannot install script</source>
        <translation>Αδυναμία εγκατάστασης σεναρίου εντολής</translation>
    </message>
    <message>
        <location filename="../gm_addscriptdialog.cpp" line="85"/>
        <source>&apos;%1&apos; installed successfully</source>
        <translation>&apos;%1&apos; εγκαταστάθηκε επιτυχώς</translation>
    </message>
</context>
<context>
    <name>GM_Downloader</name>
    <message>
        <location filename="../gm_downloader.cpp" line="144"/>
        <source>&apos;%1&apos; is already installed</source>
        <translation>&apos;%1&apos; είναι ήδη εγκατεστημένο</translation>
    </message>
</context>
<context>
    <name>GM_Manager</name>
    <message>
        <location filename="../gm_manager.cpp" line="183"/>
        <source>GreaseMonkey</source>
        <translation>GreaseMonkey</translation>
    </message>
</context>
<context>
    <name>GM_Notification</name>
    <message>
        <location filename="../gm_notification.ui" line="45"/>
        <source>This script can be installed with the GreaseMonkey plugin.</source>
        <translation>Αυτό το σενάριο χρήστη μπορεί να εγκατασταθεί με το πρόσθετο GreaseMonkey.</translation>
    </message>
    <message>
        <location filename="../gm_notification.ui" line="65"/>
        <source>Install</source>
        <translation>Εγκατάσταση</translation>
    </message>
    <message>
        <location filename="../gm_notification.cpp" line="49"/>
        <source>Cannot install script</source>
        <translation>Αδυναμία εγκατάστασης σεναρίου</translation>
    </message>
    <message>
        <location filename="../gm_notification.cpp" line="57"/>
        <source>&apos;%1&apos; installed successfully</source>
        <translation>&apos;%1&apos; εγκαταστάθηκε επιτυχώς</translation>
    </message>
</context>
<context>
    <name>GM_Settings</name>
    <message>
        <location filename="../settings/gm_settings.ui" line="14"/>
        <source>GreaseMonkey Scripts</source>
        <translation>Σενάρια εντολών χρήστη GreaseMonkey</translation>
    </message>
    <message>
        <location filename="../settings/gm_settings.ui" line="51"/>
        <source>&lt;h3&gt;GreaseMonkey Scripts&lt;/h3&gt;</source>
        <translation>&lt;h3&gt;Σενάρια εντολών χρήστη GreaseMonkey&lt;/h3&gt;</translation>
    </message>
    <message>
        <location filename="../settings/gm_settings.ui" line="73"/>
        <source>Double clicking script will show additional information</source>
        <translation>Με διπλό κλικ στο σενάριο θα εμφανιστούν επιπλέον πληροφορίες</translation>
    </message>
    <message>
        <location filename="../settings/gm_settings.ui" line="153"/>
        <source>More scripts can be downloaded from</source>
        <translation>Μπορεί να γίνει λήψη περισσότερων σεναρίων από</translation>
    </message>
    <message>
        <location filename="../settings/gm_settings.ui" line="196"/>
        <source>Open scripts directory</source>
        <translation>Άνοιγμα φακέλου σεναρίων</translation>
    </message>
    <message>
        <location filename="../settings/gm_settings.cpp" line="75"/>
        <source>Remove script</source>
        <translation>Αφαίρεση σεναρίου</translation>
    </message>
    <message>
        <location filename="../settings/gm_settings.cpp" line="76"/>
        <source>Are you sure you want to remove &apos;%1&apos;?</source>
        <translation>Είστε σίγουροι ότι θέλετε να αφαιρέσετε το &apos;%1&apos;;</translation>
    </message>
</context>
<context>
    <name>GM_SettingsScriptInfo</name>
    <message>
        <location filename="../settings/gm_settingsscriptinfo.ui" line="19"/>
        <source>Name:</source>
        <translation>Όνομα:</translation>
    </message>
    <message>
        <location filename="../settings/gm_settingsscriptinfo.ui" line="29"/>
        <source>Version:</source>
        <translation>Έκδοση:</translation>
    </message>
    <message>
        <location filename="../settings/gm_settingsscriptinfo.ui" line="39"/>
        <source>URL:</source>
        <translation>URL:</translation>
    </message>
    <message>
        <location filename="../settings/gm_settingsscriptinfo.ui" line="49"/>
        <source>Start at:</source>
        <translation>Έναρξη σε:</translation>
    </message>
    <message>
        <location filename="../settings/gm_settingsscriptinfo.ui" line="59"/>
        <source>Description:</source>
        <translation>Περιγραφή:</translation>
    </message>
    <message>
        <location filename="../settings/gm_settingsscriptinfo.ui" line="69"/>
        <source>Runs at:</source>
        <translation>Τρέχει σε:</translation>
    </message>
    <message>
        <location filename="../settings/gm_settingsscriptinfo.ui" line="79"/>
        <source>Does not run at:</source>
        <translation>Δεν τρέχει σε:</translation>
    </message>
    <message>
        <location filename="../settings/gm_settingsscriptinfo.cpp" line="27"/>
        <source>Script Details of %1</source>
        <translation>Πληροφορίες σεναρίου %1</translation>
    </message>
</context>
</TS>
